<div id="detail-pagination" class="field has-addons" style="width: 100%">
    <p class="control">
        <button class="button"
                hx-get="{{ previous_object_url }}{{ querystring }}"
                hx-replace-url="true"
                hx-select-oob="#content,#detail-pagination"
        ><
        </button>

    </p>
    {% if total_objects > 99999 %}
        <p class="control is-expanded">
            <button class="button is-fullwidth px-1"><span class="is-size-7">{{ current_object_idx }}<br>/{{ total_objects }}</span></button>
        </p>
    {% else %}
        <p class="control is-expanded">
            <button class="button is-fullwidth px-1">{{ current_object_idx }} / {{ total_objects }}</button>
        </p>
    {% endif %}
    <p class="control">
        <button class="button" hx-get="{{ next_object_url }}{{ querystring }}"
                hx-replace-url="true"
                hx-select-oob="#content,#detail-pagination"
        >>
        </button>
    </p>
</div>
