.has-icon {
  padding-left: 8px;
  padding-right: 8px;
  min-width: 40px;
}

.icon-open-related {
  background-image:url('data:image/svg+xml;charset=utf-8,%3Csvg viewBox=%22177 17 86 86%22 version=%221.2%22 xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath d=%22M240 20h20m0 0v20m0-20-40 40m40 0v20m0 0s0 20-20 20m0 0h-40m0 0s-20 0-20-20m0 0V40m0 0s0-20 20-20m20 0h-20%22 fill=%22none%22 stroke-width=%225%22 stroke-linecap=%22round%22 stroke-linejoin=%22round%22 stroke=%22%23283330%22 stroke-miterlimit=%2210%22/%3E%3C/svg%3E');
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}

.icon-envelope {
  background-image:url('data:image/svg+xml;charset=utf-8,%3Csvg width=%22240%22 height=%22120%22 viewBox=%2297 97 166 86%22 version=%221.2%22 xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath style=%22fill:none;stroke-width:5;stroke-linecap:round;stroke-linejoin:round;stroke:%23283330;stroke-opacity:1;stroke-miterlimit:10%22 d=%22M100 180h160v-80H100v80%22/%3E%3Cpath style=%22fill:none;stroke-width:5;stroke-linecap:round;stroke-linejoin:round;stroke:%23283330;stroke-opacity:1;stroke-miterlimit:10%22 d=%22m100 100 80 40 80-40%22/%3E%3C/svg%3E');
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}

.icon-clear {
  background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg width=%22360%22 height=%22360%22 viewBox=%2297 97 166 86%22 version=%221.2%22 xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath style=%22fill:none;stroke-width:5;stroke-linecap:round;stroke-linejoin:round;stroke:%23283330;stroke-opacity:1;stroke-miterlimit:10%22 d=%22M260 100v80h-80l-80-40 80-40h80m-80 0 80 80m-80 0 80-80%22/%3E%3C/svg%3E");
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}

.icon-backspace {
  background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg width=%22360%22 height=%22360%22 viewBox=%2255 94 211 132%22 version=%221.2%22 xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath style=%22fill:none;stroke-width:10;stroke-linecap:round;stroke-linejoin:round;stroke:%23283330;stroke-opacity:1;stroke-miterlimit:10%22 d=%22M260 100v120H140m120-120H140m-80 60 80-60m-80 60 80 60m20-80 60 40m-60 0 60-40%22/%3E%3C/svg%3E");
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}

.icon-delete-filter {
  background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%22http://www.w3.org/2000/svg%22 width=%22360%22 height=%22360%22 version=%221.2%22%3E%3Cpath style=%22fill:none;stroke-width:10;stroke-linecap:round;stroke-linejoin:round;stroke:%23283330;stroke-opacity:1;stroke-miterlimit:10%22 d=%22M20 340 340 20M40 60h240m40 0h20M140 340V240m0 100 80-80m0 0V160m0 0L340 60M140 200v-40M40 60H20m120 100L20 60%22/%3E%3C/svg%3E");
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}
