.header-sticky {
    position: sticky;
    top: 0;
    background: white;
}

table {
    margin-bottom: 12px !important;
}

th {
    background-color: white;
}

/*tbody > tr:hover {*/
/*    background-color: #f5f5f5;*/
/*}*/

label {
    word-break: break-word;
}

.dropdown-link:hover {
    cursor: pointer;
    background-color: #f5f5f5;
}

.link-row:hover {
    cursor: pointer;
}

.main-columns {
    padding-top: 52px;
    height: 100vh;
}

.side-panel {
    height: 100%;
    padding: 0 4px 0 0;
    border-radius: 0;
    position: sticky;
    top: 0;
}

.side-panel > .panel {
    border-radius: 0;
    height: 100%;
    overflow-y: auto;
    position: sticky;
    top: 0;
}

.info-panel {
    padding: 4px;
    border-radius: 0;
}

.info-panel > .panel {
    border-radius: 0;
    box-shadow: 0 0 0 0
}

.title {
    word-break: break-all;
}

td > a {
    display:block;
    width:100%;
}

.notification {
    word-wrap: break-word
}

.list-link {
    color: #48c78e;
}

a:link:not(.list-link) {
    color: #0a0a0a;
}

a:visited {
    color: #0a0a0a;
}

.content-column {
    height: 100%;
    overflow-y: auto;
}

.content-column > table > thead th {
    position: sticky;
    top: 0;
}

.buttons > .panel-block {
    padding: .5rem 0 .5rem .5rem;
}

.level-item > .panel-block {
    padding-left: 2px;
    padding-right: 2px;
}

.level-item > .panel-block:first-child {
    padding-left: 0;
}

.panel-block:not(:last-child) {
    border-bottom: none !important;
}

.container > .level {
    margin: 0;
    max-width: 100%;
    overflow-x: hidden;
}

.level * {
    max-width: 100%;
}

.level * p {
    word-break: break-all;
}

.columns {
    margin: 0;
}

input:focus {
    outline: 1px solid #48c78e !important;
    border: 1px solid #48c78e !important;
}

select:focus {
    outline: 1px solid #48c78e !important;
    border: 1px solid #48c78e !important;
}

.select:not(.is-multiple):not(.is-loading)::after {
    border-color: #48c78e;
}

.button:focus {
    outline: 1px solid #48c78e !important;
    border: 1px solid #48c78e !important;
}

.query-params {
    padding-left: 12px;
    margin-top: 4px;
}

.query-param {
    outline: none;
    padding-bottom: 4px;
}

.query-param > p:hover, .query-param:focus > p {
    background: lightgray;
    cursor: pointer;
    outline: none;
    border-radius: 4px;
}

.query-tag-group {
    display: flex;
    flex-direction: column;
    /*border: black 1px solid;*/
    margin-bottom: 4px;
    padding-bottom: 8px;
    border-radius: 4px;
    background-color: lightgray;
    cursor: pointer;
}

.query-tag-group > .query-tag {
    background-color: transparent;
    margin: 0;
    padding: 8px 8px 0 8px;
}

.query-tag {
    display: flex;
    flex-direction: row;
    justify-content: space-between;
    padding: 8px;
    margin-bottom: 8px;
    background-color: lightgray;
    border-radius: 4px;
    cursor: pointer;
}

.query-tag-text {
    word-break: break-word;
}

.selected-query-tag {
    background-color: #48c78e; !important;
}

.arrow:before {
    content: '\21B3';
}

.arrowless {
    text-indent: 13px;
}

.field.has-addons {
    margin-bottom: 0;
}

.field:not(:last-child) {
    margin-bottom: 0;
}

.level-is-shrinkable .level-left,
.level-is-shrinkable .level-item,
.level-is-shrinkable .level-right {
  flex-shrink: 1;
}